@@ -84,7 +84,7 @@ tidy_logistic <- function(.n = 50, .location = 0, .scale = 1, .num_sims = 1) {
       purrr::set_names("dx", "dy") %>%
       dplyr::as_tibble())) %>%
     dplyr::mutate(p = list(stats::plogis(ps, location = location, scale = scale))) %>%
-    dplyr::mutate(q = list(stats::qlogis(qs, location = location, scale = scale))) %>%
+    dplyr::mutate(q = list(stats::qlogis(tidy_scale_zero_one_vec(unlist(y)), location = location, scale = scale))) %>%
     tidyr::unnest(cols = c(x, y, d, p, q)) %>%
     dplyr::ungroup()
 
